pub struct Connection { /* private fields */ }Expand description
A connection to the Theater server with automatic reconnection
Implementations
Sourceimpl Connection
impl Connection
pub fn new(address: SocketAddr, config: Config) -> Self
Sourcepub async fn ensure_connected(&mut self) -> CliResult<()>
pub async fn ensure_connected(&mut self) -> CliResult<()>
Ensure we have an active connection, reconnecting if necessary
Sourcepub async fn send_command(
&mut self,
command: ManagementCommand,
) -> CliResult<ManagementResponse>
pub async fn send_command( &mut self, command: ManagementCommand, ) -> CliResult<ManagementResponse>
Send a command and wait for a response
Sourcepub async fn send_command_no_response(
&mut self,
command: ManagementCommand,
) -> CliResult<()>
pub async fn send_command_no_response( &mut self, command: ManagementCommand, ) -> CliResult<()>
Send a command without waiting for a response
Sourcepub async fn next_response(&mut self) -> CliResult<Option<ManagementResponse>>
pub async fn next_response(&mut self) -> CliResult<Option<ManagementResponse>>
Get the next response from the connection (for streaming operations)
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if the connection is currently active
Sourcepub fn address(&self) -> SocketAddr
pub fn address(&self) -> SocketAddr
Get the server address
Sourcepub fn last_error(&self) -> Option<&str>
pub fn last_error(&self) -> Option<&str>
Get the last connection error, if any