pub type SetupArgs = SpawnArgs;Expand description
theater setup takes the same arguments as theater spawn.
Aliased Type
pub struct SetupArgs {
pub manifest: String,
pub events: bool,
pub events_format: EventFormat,
pub save: Option<PathBuf>,
pub no_actor_logs: bool,
}Fields
manifest: StringPath or URL to the actor manifest file
events: boolOutput chain events from all actors
events_format: EventFormatFormat for event output (used with –events)
save: Option<PathBuf>Save the chain to a local directory after the actor exits.
Defaults to .chains/ in the current directory.
no_actor_logs: boolDisable actor log output to stdout